<h1 align="center">MongoDM</h1>

<p align="center">
    <em>MongoDM is simple ODM for MongoDB based on Pymongo & Pydantic</em>
</p>

## Requirements

Python 3.7+

## Installation

```bash
pip install mongodm
```
